@@ -4,7 +4,8 @@
    THEY'RE ALMOST CERTAIN TO BE SUBJECT TO INCOMPATIBLE CHANGES OR DISAPPEAR
    COMPLETELY IN FUTURE GNU MP RELEASES.
 
-Copyright 2003, 2004, 2011-2013, 2015 Free Software Foundation, Inc.
+Copyright 2003, 2004, 2011-2013, 2015, 2017, 2018 Free Software Foundation,
+Inc.
 
 This file is part of the GNU MP Library.
 
@@ -36,7 +37,6 @@ see https://www.gnu.org/licenses/.  */
 #include <stdlib.h>   /* for getenv */
 #include <string.h>
 
-#include "gmp.h"
 #include "gmp-impl.h"
 
 /* Change this to "#define TRACE(x) x" for some traces. */
@@ -174,7 +174,7 @@ struct cpuvec_t __gmpn_cpuvec = {
   __MPN(copyi_init),
   __MPN(divexact_1_init),
   __MPN(divrem_1_init),
-  __MPN(gcd_1_init),
+  __MPN(gcd_11_init),
   __MPN(lshift_init),
   __MPN(lshiftc_init),
   __MPN(mod_1_init),
@@ -261,7 +261,7 @@ __gmpn_cpuvec_init (void)
             case 5:
               TRACE (printf ("  pentium\n"));
               CPUVEC_SETUP_pentium;
-              if (model >= 4)
+              if (model == 4 || model == 8)
                 {
                   TRACE (printf ("  pentiummmx\n"));
                   CPUVEC_SETUP_pentium_mmx;
@@ -351,13 +351,13 @@ __gmpn_cpuvec_init (void)
 		case 0x2c:		/* WSM Gulftown */
 		case 0x2e:		/* NHM Beckton */
 		case 0x2f:		/* WSM Eagleton */
-	    case 0x37:		/* Silvermont */
-	    case 0x4a:		/* Silvermont */
-	    case 0x4c:		/* Airmont */
-	    case 0x4d:		/* Silvermont/Avoton */
-	    case 0x5a:		/* Silvermont */
-	    case 0x5c:		/* Goldmont */
-	    case 0x5f:		/* Goldmont */
+		case 0x37:		/* Silvermont */
+		case 0x4a:		/* Silvermont */
+		case 0x4c:		/* Airmont */
+		case 0x4d:		/* Silvermont/Avoton */
+		case 0x5a:		/* Silvermont */
+		case 0x5c:		/* Goldmont */
+		case 0x5f:		/* Goldmont */
 		  TRACE (printf ("  nehalem/westmere\n"));
                   CPUVEC_SETUP_p6_mmx;
                   CPUVEC_SETUP_p6_p3mmx;
@@ -369,20 +369,20 @@ __gmpn_cpuvec_init (void)
 		case 0x2a:		/* SBR */
 		case 0x2d:		/* SBR-EP */
 		case 0x3a:		/* IBR */
-	    case 0x3e:		/* IBR Ivytown */
-		case 0x3c:		/* Haswell */
-	    case 0x3f:		/* Haswell server */
-	    case 0x45:		/* Haswell ULT */
-	    case 0x46:		/* Crystal Well */
-	    case 0x3d:		/* Broadwell */
-	    case 0x47:		/* Broadwell */
-	    case 0x4f:		/* Broadwell server */
-	    case 0x56:		/* Broadwell microserver */
-	    case 0x4e:		/* Skylake client */
-	    case 0x55:		/* Skylake server */
-	    case 0x5e:		/* Skylake */
-	    case 0x8e:		/* Cabylake */
-	    case 0x9e:		/* Cabylake */
+		case 0x3c:		/* Haswell client */
+		case 0x3e:		/* IBR Ivytown */
+		case 0x3f:		/* Haswell server */
+		case 0x45:		/* Haswell ULT */
+		case 0x46:		/* Crystal Well */
+		case 0x3d:		/* Broadwell */
+		case 0x47:		/* Broadwell */
+		case 0x4f:		/* Broadwell server */
+		case 0x56:		/* Broadwell microserver */
+		case 0x4e:		/* Skylake client */
+		case 0x55:		/* Skylake server */
+		case 0x5e:		/* Skylake */
+		case 0x8e:		/* Kabylake */
+		case 0x9e:		/* Kabylake */
 		  TRACE (printf ("  sandybridge\n"));
                   CPUVEC_SETUP_p6_mmx;
                   CPUVEC_SETUP_p6_p3mmx;
@@ -451,11 +451,11 @@ __gmpn_cpuvec_init (void)
 	      break;
 
             case 0x14:		/* bobcat */
-	case 0x16:		/* jaguar */
+	    case 0x16:		/* jaguar */
               TRACE (printf ("  bobcat\n"));
               CPUVEC_SETUP_k7;
               CPUVEC_SETUP_k7_mmx;
-              CPUVEC_SETUP_bobcat;
+              CPUVEC_SETUP_bt1;
 	      break;
 
             case 0x15:		/* bulldozer, piledriver, steamroller, excavator */
